@@ -1,5 +1,5 @@
 gcdnet <- function(x, y, nlambda = 100, method = c("hhsvm", 
-    "logit", "sqsvm"), lambda.factor = ifelse(nobs < nvars, 0.01, 
+    "logit", "sqsvm", "ls"), lambda.factor = ifelse(nobs < nvars, 0.01, 
     1e-04), lambda = NULL, lambda2 = 0, pf = rep(1, nvars), pf2 = rep(1, nvars), exclude, 
     dfmax = nvars + 1, pmax = min(dfmax * 1.2, nvars), standardize = TRUE, 
     eps = 1e-08, maxit = 1e+06, delta = 2) {
@@ -56,13 +56,19 @@ gcdnet <- function(x, y, nlambda = 100, method = c("hhsvm",
         nlam <- as.integer(length(lambda))
     }
     #################################################################################
-    fit <- switch(method, hhsvm = hsvmpath(x, y, nlam, flmin, 
+    fit <- switch(method, 
+	hhsvm = hsvmpath(x, y, nlam, flmin, 
         ulam, isd, eps, dfmax, pmax, jd, pf, pf2, maxit, lam2, delta, 
-        nobs, nvars, vnames), logit = logitpath(x, y, nlam, flmin, 
+        nobs, nvars, vnames), 
+	logit = logitpath(x, y, nlam, flmin, 
         ulam, isd, eps, dfmax, pmax, jd, pf, pf2, maxit, lam2, nobs, 
-        nvars, vnames), sqsvm = sqsvmpath(x, y, nlam, flmin, 
+        nvars, vnames), 
+	sqsvm = sqsvmpath(x, y, nlam, flmin, 
         ulam, isd, eps, dfmax, pmax, jd, pf, pf2, maxit, lam2, nobs, 
-        nvars, vnames))
+        nvars, vnames),
+	ls = lspath(x, y, nlam, flmin, 
+	    ulam, isd, eps, dfmax, pmax, jd, pf, pf2, maxit, lam2, nobs, 
+	    nvars, vnames))
     if (is.null(lambda)) 
         fit$lambda <- lamfix(fit$lambda)
     fit$call <- this.call
